==> drill-java-exec-1.10.0.jar: org/apache/drill/exec/expr/fn/impl/gcast/CastFloat8BigInt.java <==

/*******************************************************************************

 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.drill.exec.expr.fn.impl.gcast;

import org.apache.drill.exec.expr.DrillSimpleFunc;
import org.apache.drill.exec.expr.annotations.FunctionTemplate;
import org.apache.drill.exec.expr.annotations.FunctionTemplate.NullHandling;
import org.apache.drill.exec.expr.annotations.Output;
import org.apache.drill.exec.expr.annotations.Param;
import org.apache.drill.exec.expr.holders.*;
import javax.inject.Inject;
import io.netty.buffer.DrillBuf;
import org.apache.drill.exec.record.RecordBatch;

/*
 * This class is generated using freemarker and the CastFunctions.java template.
 */

@SuppressWarnings("unused")
@FunctionTemplate(name = "castBIGINT", scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
public class CastFloat8BigInt implements DrillSimpleFunc{

  @Param Float8Holder in;
  @Output BigIntHolder out;

  public void setup() {}

  public void eval() {
    boolean sign = (in.value < 0);
    in.value = java.lang.Math.abs(in.value);
    double fractional = in.value % 1;
    int digit = ((int) (fractional * 10));
    int carry = 0;
    if (digit > 4) {
      carry = 1;
    }
    out.value = ((long) in.value) + carry;
    if (sign == true) {
      out.value *= -1;
    }
  }
}

==> drill-java-exec-1.12.0.jar: org/apache/drill/exec/expr/fn/impl/gcast/CastFloat8BigInt.java <==

/*******************************************************************************

 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.drill.exec.expr.fn.impl.gcast;

import org.apache.drill.exec.expr.DrillSimpleFunc;
import org.apache.drill.exec.expr.annotations.FunctionTemplate;
import org.apache.drill.exec.expr.annotations.FunctionTemplate.NullHandling;
import org.apache.drill.exec.expr.annotations.Output;
import org.apache.drill.exec.expr.annotations.Param;
import org.apache.drill.exec.expr.holders.*;
import javax.inject.Inject;
import io.netty.buffer.DrillBuf;
import org.apache.drill.exec.record.RecordBatch;

/*
 * This class is generated using freemarker and the CastFunctions.java template.
 */

@SuppressWarnings("unused")
@FunctionTemplate(name = "castBIGINT",
                  scope = FunctionTemplate.FunctionScope.SIMPLE,
                  nulls = NullHandling.NULL_IF_NULL)
public class CastFloat8BigInt implements DrillSimpleFunc {

  @Param Float8Holder in;
  @Output BigIntHolder out;

  public void setup() {}

  public void eval() {
    double fractional = in.value % 1;
    int digit = ((int) (fractional * 10));
    int carry = 0;
    if (java.lang.Math.abs(digit) > 4) {
      carry = (int) java.lang.Math.signum(digit);
    }
    out.value = (long) (in.value + carry);
  }
}
